@@ -1,4 +1,4 @@
-utils::globalVariables(c("counter", "Prediction", "input.data", "old.d", "old.d2", "surv", "event", "n.risk", "part"))
+if (getRversion() >= "2.15.1") utils::globalVariables(c("counter", "Prediction", "input.data", "old.d", "old.d2", "surv", "event", "n.risk", "part"))
 
 DynNom.coxph <- function(model, data,
                          clevel = 0.95, covariate = c("slider", "numeric"),
@@ -6,6 +6,11 @@ DynNom.coxph <- function(model, data,
 
   data <- data.frame(data)
 
+  tt <- names(attr(model$terms, "dataClasses"))[1]
+  if (substr(tt,1,5) != "Surv("){
+    stop("Error in model syntax: 'time' and 'status' do not find in model's terms")
+  }
+
   if (length(dim(data)) > 2)
     stop("Error in data format: dataframe format required")
 
@@ -37,14 +42,15 @@ DynNom.coxph <- function(model, data,
   }
 
   for(i in 2:length(names(attr(model$terms, "dataClasses")))) {
-    com1=numeric(length(names(data)))
+    com1 = numeric(length(names(data)))
     for(j in 1:length(names(data))) {
-      if (names(attr(model$terms, "dataClasses"))[i]==names(data)[j]) com1[j]=1
+      if (names(attr(model$terms, "dataClasses"))[i] == names(data)[j]) com1[j] = 1
     }
-    if (sum(com1)==0)
+    if (sum(com1) == 0)
       stop("Error in model syntax: some of model's terms do not match to variables' name in dataset")
   }
 
+  coll <- c(1:50)
   covariate <- match.arg(covariate)
   ptype <- match.arg(ptype)
   input.data <- NULL
@@ -110,7 +116,6 @@ DynNom.coxph <- function(model, data,
         }
       }
 
-      tt <- names(attr(model$terms, "dataClasses"))[1]
       dd <- unlist(strsplit(substr(tt, 6, nchar(tt) - 1), "[,]"))
       tim <- dd[1]
       sts <- substr(dd[2], 2, nchar(dd[2]))
@@ -386,7 +391,7 @@ DynNom.coxph <- function(model, data,
               if (ptype == "st") {
                 pl <- isolate({
                   p2 <- ggplot(data = dat.p())
-                  p2 <- p2 + geom_step(aes(x = time, y = surv, alpha = n.risk, color = as.factor(part), group = part))
+                  p2 <- p2 + geom_step(aes(x = time, y = surv, alpha = n.risk, group = part), color = coll[dat.p()$part])
                   p2 <- p2 + ylim(0, 1) + xlim(0, max(dat.p()$time) * 1.05)
                   p2 <- p2 + labs(title = "Estimated Survival Probability", x = "Follow Up Time", y = "S(t)") + theme_bw()
                   p2 <- p2 + theme(text = element_text(face = "bold", size = 14), legend.position = "none")
@@ -395,7 +400,7 @@ DynNom.coxph <- function(model, data,
               if (ptype == "1-st") {
                 pl <- isolate({
                   p2 <- ggplot(data = dat.p())
-                  p2 <- p2 + geom_step(aes(x = time, y = event, alpha = n.risk, color = as.factor(part), group = part))
+                  p2 <- p2 + geom_step(aes(x = time, y = event, alpha = n.risk, group = part), color = coll[dat.p()$part])
                   p2 <- p2 + ylim(0, 1) + xlim(0, max(dat.p()$time) * 1.05)
                   p2 <- p2 + labs(title = "Estimated Probability", x = "Follow Up Time", y = "F(t)")
                   p2 <- p2 + theme_bw() + theme(text = element_text(face = "bold", size = 14), legend.position = "none")
@@ -406,7 +411,7 @@ DynNom.coxph <- function(model, data,
               if (ptype == "st") {
                 pl <- isolate({
                   p2 <- ggplot(data = dat.p())
-                  p2 <- p2 + geom_step(aes(x = time, y = surv, color = as.factor(part), group = part))
+                  p2 <- p2 + geom_step(aes(x = time, y = surv, group = part), color = coll[dat.p()$part])
                   p2 <- p2 + ylim(0, 1) + xlim(0, max(dat.p()$time) * 1.05)
                   p2 <- p2 + labs(title = "Estimated Survival Probability", x = "Follow Up Time", y = "S(t)") + theme_bw()
                   p2 <- p2 + theme(text = element_text(face = "bold", size = 14), legend.position = "none")
@@ -415,7 +420,7 @@ DynNom.coxph <- function(model, data,
               if (ptype == "1-st") {
                 pl <- isolate({
                   p2 <- ggplot(data = dat.p())
-                  p2 <- p2 + geom_step(aes(x = time, y = event, color = as.factor(part), group = part))
+                  p2 <- p2 + geom_step(aes(x = time, y = event, group = part), color = coll[dat.p()$part])
                   p2 <- p2 + ylim(0, 1) + xlim(0, max(dat.p()$time) * 1.05)
                   p2 <- p2 + labs(title = "Estimated Probability", x = "Follow Up Time", y = "F(t)")
                   p2 <- p2 + theme_bw() + theme(text = element_text(face = "bold", size = 14), legend.position = "none")
